/* DROP TABLE IF EXISTS sample8; */
 CREATE TABLE IF NOT EXISTS sample8(
	app_request_nbr bigint 		/* eg. 10576872 */  
) 
COMMENT="This MySQL table was defined by schemawiz for loading the csv file BMONAS-Finalresend.csv, delimiter (~)"; 
